#include <gui/model/Model.hpp>
#include <gui/model/ModelListener.hpp>

#ifndef SIMULATOR
#include "FreeRTOS.h"
#include "queue.h"
#include "task.h"
#include "condenser.h"

extern "C"
{
    extern xQueueHandle condenser_msg_q;
    xQueueHandle gui_msg_q;
}

#endif

Model::Model() : modelListener(0)
{
#ifndef SIMULATOR
    gui_msg_q = xQueueGenericCreate(1, 1, 0);
#endif
}

void Model::tick()
{
#ifndef SIMULATOR
    // Check for messages from backend, with zero timeout
    uint8_t msg = 0;
    if (xQueueReceive(gui_msg_q, &msg, 0) == pdTRUE)
    {
        if (msg == CONDENSER_ALARM_SET)
        {
            // Notify current presenter that an alarm is active
            modelListener->condenserAlarmOn();
        }
        else if (msg == CONDENSER_ALARM_CLEAR)
        {
            // Notify current presenter that an alarm is no longer active
            modelListener->condenserAlarmOff();
        }
    }
#endif
}

void Model::turnCondenserOn()
{
#ifndef SIMULATOR
    uint8_t msg = CONDENSER_ON;
    if (condenser_msg_q)
    {
        // Notify condenser task to start (blinking LED)
        xQueueSend(condenser_msg_q, &msg, 0);
    }
#endif
}

